%define api 5
%define major 5
%define oname qt5

%define module qtconnectivity

%define qtbluetooth %mklibname qt%{api}bluetooth %{major}
%define qtbluetoothd %mklibname qt%{api}bluetooth -d
%define qtnfc %mklibname qt%{api}nfc %{major}
%define qtnfcd %mklibname qt%{api}nfc -d

# Requires qdoc5 and qt5-tools to build
%bcond_without docs

Summary:	Version 5 of the Qt toolkit (%{module} packages)
Name:		qt5-%{module}
Version:	5.6.1
Release:	1
License:	LGPLv3+
Group:		Development/KDE and Qt
Url:		http://qt-project.org/
Source0:	http://ftp.fau.de/qtproject/official_releases/qt/%(echo %{version} |cut -d. -f1-2)/%{version}/submodules/%{module}-opensource-src-%{version}.tar.xz
Source100:	%{name}.rpmlintrc
BuildRequires:	pkgconfig(bluez)
BuildRequires:	pkgconfig(Qt5Concurrent) >= %{version}
BuildRequires:	pkgconfig(Qt5Core) >= %{version}
BuildRequires:	pkgconfig(Qt5DBus) >= %{version}
BuildRequires:	pkgconfig(Qt5Gui) >= %{version}
BuildRequires:	pkgconfig(Qt5Network) >= %{version}
BuildRequires:	pkgconfig(Qt5Qml) >= %{version}
BuildRequires:	pkgconfig(Qt5Quick) >= %{version}
BuildRequires:	pkgconfig(Qt5Widgets) >= %{version}
%if %{with docs}
BuildRequires:	qdoc5
BuildRequires:	qt5-tools
%endif

%description
Version 5 of the Qt toolkit (%{module} packages).

#----------------------------------------------------------------------------

%package -n %{qtbluetooth}
Summary:	Qt Bluetooth library
Group:		System/Libraries

%description -n %{qtbluetooth}
Qt Bluetooth library.

%files -n %{qtbluetooth}
%{_qt5_bindir}/sdpscanner
%{_qt5_libdir}/libQt%{api}Bluetooth.so.%{major}*
%if "%{_qt5_libdir}" != "%{_libdir}"
%{_libdir}/libQt%{api}Bluetooth.so.%{major}*
%endif
%{_qt5_prefix}/qml/QtBluetooth

#----------------------------------------------------------------------------

%package -n %{qtbluetoothd}
Summary:	Development files for version 5 of the QtBluetooth library
Group:		Development/KDE and Qt
Requires:	%{qtbluetooth} = %{EVRD}
Requires:	qmake%{api}
Conflicts:	qmake5 < 5.6.0

%description -n %{qtbluetoothd}
Development files for version 5 of the QtBluetooth library.

%files -n %{qtbluetoothd}
%{_qt5_includedir}/QtBluetooth
%{_qt5_libdir}/libQt%{api}Bluetooth.so
%{_qt5_libdir}/libQt%{api}Bluetooth.prl
%{_qt5_libdir}/cmake/Qt%{api}Bluetooth
%{_qt5_libdir}/pkgconfig/Qt%{api}Bluetooth.pc
%if "%{_qt5_libdir}" != "%{_libdir}"
%{_libdir}/pkgconfig/Qt%{api}Bluetooth.pc
%endif
%{_qt5_prefix}/mkspecs/modules/qt_lib_bluetooth.pri
%{_qt5_prefix}/mkspecs/modules/qt_lib_bluetooth_private.pri

#----------------------------------------------------------------------------

%package -n %{qtnfc}
Summary:	Qt NFC library
Group:		System/Libraries

%description -n %{qtnfc}
Qt NFC library.

NFC is an extremely short-range (less than 20 centimeters) wireless technology
and has a maximum transfer rate of 424 kbit/s. NFC is ideal for transferring
small packets of data when two devices are touched together.

%files -n %{qtnfc}
%{_qt5_libdir}/libQt%{api}Nfc.so.%{major}*
%if "%{_qt5_libdir}" != "%{_libdir}"
%{_libdir}/libQt%{api}Nfc.so.%{major}*
%endif
%{_qt5_prefix}/qml/QtNfc

#----------------------------------------------------------------------------

%package -n %{qtnfcd}
Summary:	Development files for version 5 of the QtNfc library
Group:		Development/KDE and Qt
Requires:	%{qtnfc} = %{EVRD}
Requires:	qmake%{api}
Conflicts:	qmake5 < 5.6.0

%description -n %{qtnfcd}
Development files for version 5 of the QtNfc library.

%files -n %{qtnfcd}
%{_qt5_includedir}/QtNfc
%{_qt5_libdir}/libQt%{api}Nfc.so
%{_qt5_libdir}/libQt%{api}Nfc.prl
%{_qt5_libdir}/cmake/Qt%{api}Nfc
%{_qt5_libdir}/pkgconfig/Qt%{api}Nfc.pc
%if "%{_qt5_libdir}" != "%{_libdir}"
%{_libdir}/pkgconfig/Qt%{api}Nfc.pc
%endif
%{_qt5_prefix}/mkspecs/modules/qt_lib_nfc.pri
%{_qt5_prefix}/mkspecs/modules/qt_lib_nfc_private.pri

#----------------------------------------------------------------------------

%if %{with docs}
%package doc
Summary:	Qt QCH documentation for %{name}
Group:		Documentation
Conflicts:	qt5-doc < 5.6.0
BuildArch:	noarch

%description doc
Qt QCH documentation for %{name}.

%files doc
%{_qt5_docdir}/qtbluetooth.qch
%{_qt5_docdir}/qtnfc.qch
%endif

#----------------------------------------------------------------------------

%package examples
Summary:	Example applications for %{name}
Group:		Development/KDE and Qt
Conflicts:	qt5-examples < 5.6.0

%description examples
Example applications for %{name}.

%files examples
%{_qt5_exampledir}/bluetooth/
%{_qt5_exampledir}/nfc/

#----------------------------------------------------------------------------

%prep
%setup -qn %{module}-opensource-src-%{version}

%build
%qmake_qt5
%make STRIP=true

%if %{with docs}
%make docs
%endif

%install
make install STRIP=true INSTALL_ROOT=%{buildroot}

%if %{with docs}
make install_qch_docs INSTALL_ROOT=%{buildroot}
%endif

%if "%{_qt5_libdir}" != "%{_libdir}"
pushd %{buildroot}%{_libdir}
ln -s ../%{_lib}/qt%{api}/%{_lib}/*.so.* .
mkdir pkgconfig
cd pkgconfig
ln -s ../../%{_lib}/qt%{api}/%{_lib}/pkgconfig/*.pc .
popd
%endif

# QMAKE_PRL_BUILD_DIR = /builddir/build/BUILD/qt-everywhere-opensource-src-5.4.0-beta/qtwayland/src/client
## .prl/.la file love
# nuke .prl reference(s) to %%buildroot, excessive (.la-like) libs
pushd %{buildroot}%{_qt5_libdir}
for prl_file in libQt5*.prl ; do
  sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" ${prl_file}
  if [ -f "$(basename ${prl_file} .prl).so" ]; then
    rm -fv "$(basename ${prl_file} .prl).la"
    sed -i -e "/^QMAKE_PRL_LIBS/d" ${prl_file}
  fi
done
popd

%changelog

* Sun Jun 12 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 5.6.1-1
- (d4afbb1) New version 5.6.1


